#*******************************************************************************
#
# Example script demonstrating usage of IDMEF::Message::Storage::Mongo and
# Mentat::Handyman libraries for generating and direct storage of IDMEF messages.
#
# More examples of how to use the libraries used in this script can be found in
# their test scripts.
#
#*******************************************************************************

use strict;
use warnings;

use IDMEF::Message::Factory;
use IDMEF::Message::Storage::Mongo;
use Mentat::Handyman;

#-------------------------------------------------------------------------------
# 1. Prepare database storage driver
#-------------------------------------------------------------------------------
# IDMEF::Message::Storage::Mongo->new($convertor, $connection, $database, $collection)
# (See the manual documentation for more details)
# Use default values for all constructor arguments
# $convertor: IDMEF::Message::Convertor::Mongo
# $connection: undef
# $database: 'mentat'
# $collection: 'idmef'
my $engine = IDMEF::Message::Storage::Mongo->new();

# or set own arguments

#my $engine = IDMEF::Message::Storage::Mongo->new(My::Convertor->new(), ['hostname','example.com:12345','query_timeout', '10'], 'my-database', 'my-collection');

#-------------------------------------------------------------------------------
# 2. Prepare mentat handyman for creating IDMEF messages
#-------------------------------------------------------------------------------

# Setup builder configurations
my $BUILDER_CONFIG = {
		'name' => 'somehost.domain',
		'type' => 'Honeypot'
		'sw'   => 'DetectionSW'
		'note' => 'Node note'
	};

# Create handyman object
# Mentat::Handyman->new(($template_file, $temp_folder, $pickup_folder, $builder_config, $template_id);
# (See the manual documentation for more details)
my $handyman = Mentat::Handyman->new('./conf/templates.conf', '/var/tmp', '/var/mentat/pickup', $BUILDER_CONFIG, 'ssh-001');

my ($idmef_message, $record_id);

#-------------------------------------------------------------------------------
# 3A. Generate IDMEF message and store it directly
#-------------------------------------------------------------------------------

# Attempt to generate the IDMEF message according to the template
$idmef_message = $handyman->generate('ssh-001', {'detect_time' => 1356955200}, 'publickey', 'root', '12.34.56.78', 56634, "Dec 31 12:00:00 somehost sshd[12345]: Accepted publickey for root from 12.34.56.78 port 56634 ssh2");

# And store it
$record_id = $engine->insert($idmef_message);

#-------------------------------------------------------------------------------
# 3B. Generate IDMEF message to file and store it from that file
#-------------------------------------------------------------------------------

# Attempt to generate the IDMEF message according to the template and store it to the file
my ($rv, $filename) = $handyman->generate_to_file('ssh-001', {'detect_time' => 1356955200}, 'publickey', 'root', '12.34.56.78', 56634, "Dec 31 12:00:00 somehost sshd[12345]: Accepted publickey for root from 12.34.56.78 port 56634 ssh2");

$idmef_message = IDMEF::Message::Factory->from_file($filename);

# Insert the IDMEF::Message object to the database
$record_id = $engine->insert($idmef_message);
